@@ -5,7 +5,11 @@ test_that("tibble_abort()", {
   }
   cnd <- tryCatch(abort_foo(), error = identity)
 
-  expect_s3_class(cnd, c("tibble_error_foo", "tibble_error", "rlang_error", "error", "condition"), exact = TRUE)
+  expect_s3_class(
+    cnd,
+    c("tibble_error_foo", "tibble_error", "rlang_error", "error", "condition"),
+    exact = TRUE
+  )
   expect_equal(cnd$message, "message")
   expect_equal(cnd$foo, 42)
   expect_equal(cnd$bar, 7)
